# {{ appname }}

## Setup

- [Install Gramex 1.x](https://gramener.com/gramex/guide/install/)
- Clone this repository
- From the repo folder, run `gramex setup .`
- From the repo folder, run `gramex`

## Contributions

- {{ author }} <{{ email }}>
